summaryrefslogtreecommitdiffstats
path: root/kmail/kmmessage.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmmessage.h')
-rw-r--r--kmail/kmmessage.h34
1 files changed, 17 insertions, 17 deletions
diff --git a/kmail/kmmessage.h b/kmail/kmmessage.h
index 9acaa7f1d..ebc8c78ef 100644
--- a/kmail/kmmessage.h
+++ b/kmail/kmmessage.h
@@ -150,13 +150,13 @@ public:
}
/** Mark the message as deleted */
- void del() { seStatus(KMMsgStatusDeleted); }
+ void del() { setqStatus(KMMsgStatusDeleted); }
/** Undelete the message. Same as touch */
- void undel() { seStatus(KMMsgStatusOld); }
+ void undel() { setqStatus(KMMsgStatusOld); }
/** Touch the message - mark it as read */
- void touch() { seStatus(KMMsgStatusOld); }
+ void touch() { setqStatus(KMMsgStatusOld); }
/** Create a new message that is a reply to this message, filling all
required header fields with the proper values. The returned message
@@ -210,9 +210,9 @@ public:
void sanitizeHeaders( const TQStringList& whiteList = TQStringList() );
/** Parse the string and create this message from it. */
- void fromDwString(const DwString& str, bool seStatus=false);
- void fromString(const TQCString& str, bool seStatus=false);
- void fromByteArray(const TQByteArray & ba, bool seStatus=false);
+ void fromDwString(const DwString& str, bool setqStatus=false);
+ void fromString(const TQCString& str, bool setqStatus=false);
+ void fromByteArray(const TQByteArray & ba, bool setqStatus=false);
/** Return the entire message contents in the DwString. This function
is *fast* even for large message since it does *not* involve a
@@ -243,7 +243,7 @@ public:
TQCString headerAsSendableString() const;
/**
- * Remove all private header fields: *Status: and X-KMail-*
+ * Remove all private header fields: *tqStatus: and X-KMail-*
**/
void removePrivateHeaderFields();
@@ -545,7 +545,7 @@ public:
*/
void setBodyFromUnicode( const TQString & str, DwEntity *entity = 0 );
- /** Returns the body part decoded to unicode.
+ /** Returns the body part decoded to tqunicode.
**/
TQString bodyToUnicode(const TQTextCodec* codec=0) const;
@@ -746,7 +746,7 @@ public:
static TQString guessEmailAddressFromLoginName( const TQString& userName );
/**
- * Given argument msg add quoting characters and relayout for max width maxLength
+ * Given argument msg add quoting characters and retqlayout for max width maxLength
* @param msg the string which it to be quoted
* @param maxLineLength reformat text to be this amount of columns at maximum, adding
* linefeeds at word boundaries to make it fit.
@@ -822,11 +822,11 @@ public:
ulong UID() const;
void setUID(ulong uid);
- /** Status of the message. */
- KMMsgStatus status() const { return mStatus; }
+ /** tqStatus of the message. */
+ KMMsgtqStatus status() const { return mtqStatus; }
/** Set status and mark dirty. */
- void seStatus(const KMMsgStatus status, int idx = -1);
- void seStatus(const char* s1, const char* s2=0) { KMMsgBase::seStatus(s1, s2); }
+ void setqStatus(const KMMsgtqStatus status, int idx = -1);
+ void setqStatus(const char* s1, const char* s2=0) { KMMsgBase::setqStatus(s1, s2); }
/** Set encryption status of the message. */
void setEncryptionState(const KMMsgEncryptionState, int idx = -1);
@@ -844,11 +844,11 @@ public:
KMMsgMDNSentState mdnSentState() const { return mMDNSentState; }
- /** Links this message to @p aMsg, setting link type to @p aStatus. */
- void link(const KMMessage *aMsg, KMMsgStatus aStatus);
+ /** Links this message to @p aMsg, setting link type to @p atqStatus. */
+ void link(const KMMessage *aMsg, KMMsgtqStatus atqStatus);
/** Returns the information for the Nth link into @p retMsg
- * and @p reStatus. */
- void getLink(int n, ulong *retMsgSerNum, KMMsgStatus *reStatus) const;
+ * and @p retqStatus. */
+ void getLink(int n, ulong *retMsgSerNum, KMMsgtqStatus *retqStatus) const;
/** Convert wildcards into normal string */
TQString formatString(const TQString&) const;